import csv
import os
import re

from core.Bean import Bean

fieldnames = ['ID', 'File index', 'Number of rows', 'Row position', 'Top Category', 'Inner Category', 'Text start', 'Text stop', 'Number of characters', 'Number of words', 'File new path', 'File old path']




class CommentsList:
    def __init__(self, args):
        # Create a global index CSV file
        outCSVFile = open(args.globalIndex, 'w', newline='')
        outWriter = csv.DictWriter(outCSVFile, fieldnames=fieldnames)
        outWriter.writeheader()
        outCSVDict = {}
        globalIndex = 0
        id = 0

        # Create and clean destination directory
        wPath = os.path.normpath(args.output)
        wPathInt = os.path.normpath(args.output) + os.sep + "int"
        wPathDiv = os.path.normpath(args.output) + os.sep + "div"
        wPathSplit = os.path.normpath(args.output) + os.sep + "split"
        wPathCat = os.path.normpath(args.output) + os.sep + "cat"
        ##print(wPath)
        if os.path.exists(wPath):
            for root, dirs, files in os.walk(wPath, topdown=False):
                for name in files:
                    os.remove(os.path.join(root, name))
                for name in dirs:
                    os.rmdir(os.path.join(root, name))
            os.rmdir(wPath)
        os.makedirs(wPath)
        os.makedirs(wPathInt)
        os.makedirs(wPathDiv)
        os.makedirs(wPathSplit)
        os.makedirs(wPathCat)

        #beanList = []
        out = open(args.input, "r")
        lines = out.read().splitlines()
        for line in lines:
            ##print(line)
            if 'sources/example' in line:
                fileOldPath = line.split(args.separator)[0]
                outCSVDict['ID'] = id
                 #if len(beanList) > 0:
                 #   self.flushDataToCSV(outCSVFile, beanList)
                beanList = []
                id += 1
            else:
                columns = line.split(args.separator)
                if not "uniq" in columns[0]:
                    start = columns[1]
                    stop = columns[2]
                    if int(start) > int(stop):
                        temp = start
                        start = stop
                        stop = temp
                    b = Bean()
                    b.start = start
                    b.stop = stop
                    b.category = columns[3]
                    b.topCategory = b.category.split('->')[0]
                    b.innerCategory = b.category.split('->')[1]
                    b.expl = columns[4]
                    b.id = globalIndex
                    b.filePath = fileOldPath


                    # Extract text from source file
                    text, rowPosition = self.extractTextFromFile(b.filePath, int(b.start), int(b.stop))
                    b.text = text

                    # Store files by category
                    dirPath = os.path.normpath(wPathCat) + os.sep + b.innerCategory.strip().lower()
                    if not os.path.exists(dirPath):
                        os.makedirs(dirPath)
                    filePath = os.path.normpath(dirPath) + os.sep + str(b.id) + ".txt"
                    self.createTextFile(filePath, b.text)

                    beanList.append(b)

                    # Create a xxx.txt file with extracted text
                    fileNewPath = os.path.normpath(wPathInt) + os.sep + str(globalIndex) + ".txt"
                    self.createTextFile(fileNewPath, text)
                    fileSplitPath = os.path.normpath(wPathSplit) + os.sep + str(globalIndex) + "_split.txt"
                    self.createSplitFile(fileSplitPath, text)

                    localIndex = 0
                    for row in text.split('\n'):
                        # Create a xxx.txt file for each row with extracted text
                        fileNewPath = os.path.normpath(wPathDiv) + os.sep + str(globalIndex) + "_" + str(localIndex) + ".txt"
                        self.createTextFile(fileNewPath, row)
                        fileSplitPath = os.path.normpath(wPathSplit) + os.sep + str(globalIndex) + "_" + str(localIndex) + "_split.txt"
                        self.createSplitFile(fileSplitPath, row)
                        localIndex += 1

                    # Update gloabl index CSV file
                    outCSVDict['File index'] = globalIndex                  # Numeric unique index of the file
                    outCSVDict['Number of rows'] = localIndex               # Number of rows that are present in the comment
                    outCSVDict['Row position'] = rowPosition                # Number of the row in the origin file
                    outCSVDict['Top Category'] = b.topCategory.lower()
                    outCSVDict['Inner Category'] = b.innerCategory.lower()
                    outCSVDict['Text start'] = b.start                      # Position of the first character
                    outCSVDict['Text stop'] = b.stop                        # Position of the last character of the whole comment
                    outCSVDict['Number of characters'] = len(text)          # Number of character of whole comment
                    outCSVDict['Number of words'] = 0                       # Number of extracted words
                    outCSVDict['File new path'] = os.path.normpath(wPath)   # File path without index reference
                    outCSVDict['File old path'] = fileOldPath
                    outWriter.writerow(outCSVDict)
                    outCSVFile.flush()

                    globalIndex += 1

        #if len(beanList) > 0:
        #    self.flushDataToCSV(outCSVFile, beanList)
        out.close()

    def flushDataToCSV(self, outCSVFile, beanList):
        for i in range(0, len(beanList)):
            iStart = beanList[i].start
            iStop = beanList[i].stop
            for j in range(0, len(beanList)):
                if i != j:
                    jStart = beanList[j].start
                    jStop = beanList[j].stop

                    if iStart < jStart and iStop < jStart:
                        start = iStart
                        stop = iStop
                        text, rowPosition = self.extractTextFromFile(beanList[i].filePath, int(start), int(stop))
                    elif iStart < jStart and iStop > jStart and jStop > iStop:
                        start = iStart
                        stop = jStop
                        text, rowPosition = self.extractTextFromFile(beanList[i].filePath, int(start), int(stop))
                    elif iStart <= jStart and jStart < iStop and jStop < iStop:
                        start1 = iStart
                        stop1 = jStop
                        start2 = jStop
                        stop2 = iStop
                        text1, rowPosition1 = self.extractTextFromFile(beanList[i].filePath, int(start1), int(stop1))
                        text2, rowPosition2 = self.extractTextFromFile(beanList[i].filePath, int(start2), int(stop2))
                    elif iStart >= jStart and iStart > jStop and iStop > jStop:
                        start = jStop
                        stop = iStop
                        text, rowPosition = self.extractTextFromFile(beanList[i].filePath, int(start), int(stop))
                    elif iStart > jStart and iStop < jStop:
                        start = iStart
                        stop = iStop
                        text, rowPosition = self.extractTextFromFile(beanList[i].filePath, int(start), int(stop))
                    elif iStart > jStop and iStop > jStop:
                        start = iStart
                        stop = iStop
                        text, rowPosition = self.extractTextFromFile(beanList[i].filePath, int(start), int(stop))
                    else:
                        print("Non funziona")


    def createTextFile(self, path, text):
        out = open(path, "w")
        out.write(text)
        out.close()

    def createSplitFile(self, path, text):
        out = open(path, "w")

        l2 = []
        l1 = re.compile('@\w+|\w+|[\*\\/]+').findall(text)
        for word in l1:
            if self.isAllWordLowerCase(word):
                l2.append(word)
            elif self.isAllWordUpperCase(word):
                l2.append(word)
            else:
                g = re.findall('\S(?:[A-Z]*(?![a-z])|[a-z]*)', word)
                for w in g:
                    l2.append(w)

        for word in l2:
            out.write(word)
            out.write("\n")
        out.close()

    def isAllWordUpperCase(self, word):
        ret = True
        for c in word:
            if c.islower():
                ret = False
        return ret

    def isAllWordLowerCase(self, word):
        ret = True
        for c in word:
            if c.isupper():
                ret = False
        return ret

    def extractTextFromFile(self, path, start, stop):

        out = open(path, "r")
        allText = out.read()
        if start < stop:
            row = len(allText[0:start].split('\n'))
            text = allText[start:stop]
        elif stop < start:
            row = len(allText[0:start].split('\n'))
            text = allText[stop:start]
        else:
            row = -1
            text = ""
            print("Errore")

        # Remove last \n
        text = text.rstrip()

        return text, row
