import csv
import operator
import os
import re
import threading

from Features.Features import Features
from Features.FeaturesThreading import FeaturesThreading
from core.CommentBean import CommentBean


class FeaturesExtractor:
    def __init__(self, args):
        print(args.globalIndex)

        self.commentsList = []

        inputFile = open(args.globalIndex, newline='')
        inReader = csv.DictReader(inputFile)
        for row in inReader:
            ##print(row)
            cb = CommentBean()
            cb.id = row['ID']
            cb.fileIndex = row['File index']
            cb.filePath = row['File old path']
            cb.numberOfRows = row['Number of rows']
            cb.rowPosition = row['Row position']
            cb.topCategory = row['Top Category']
            cb.innerCategory = row['Inner Category']
            cb.numberOfCharacters = row['Number of characters']
            cb.numberOfWords = row['Number of words']

            # Extract text from main file (all rows together
            filePath = os.path.normpath(row['File new path']) + os.sep + "int" + os.sep + cb.fileIndex + ".txt"
            cb.text = self.readTextFromFile(filePath)
            filePath = os.path.normpath(row['File new path']) + os.sep + "split" + os.sep + cb.fileIndex + "_split.txt"
            cb.split = self.readSplitFromFile(filePath)

            # Extract text from splitted by row files
            numberOfLines = int(row['Number of rows'])
            for i in range(0, numberOfLines):
                filePath = os.path.normpath(row['File new path']) + os.sep + "int" + os.sep + cb.fileIndex + ".txt"
                text = self.readTextFromFile(filePath)
                cb.textList.append(text)
                filePath = os.path.normpath(row['File new path']) + os.sep + "split" + os.sep + cb.fileIndex + "_split.txt"
                split = self.readSplitFromFile(filePath)
                cb.splitList.append(split)

            # Append bean to list
            self.commentsList.append(cb)

        # Create the bag of unique words
        bagOfUniqueWords = self.createBagOfUniqueWords(self.commentsList, args)
        # self.printBag(bagOfUniqueWords, args)
        # Remove features word with lower occurance
        reducedBag = self.removeWords(bagOfUniqueWords, args.occurrence)
        self.printBag(reducedBag, args)

        # Create the feature CSV file
        featureHeader = self.createFeatureHeader(reducedBag)
        csvWriterTraining = self.createFeatureCSVFile(args.training, featureHeader)
        csvWriterTesting = self.createFeatureCSVFile(args.testing, featureHeader)
        # csvWriter.writerow(outDict)

        # Rexex in thread way
        #ss = ['Summary', 'Expand', 'Rational', 'Deprecation', 'Usage', 'Exception', 'TODO', 'Incomplete', 'Commented code', 'Directive', 'Formatter', 'License', 'Ownership', 'Pointer', 'Automatic generated']
        #threads = {}
        #for s in ss:
        #    threads[s] = FeaturesThreading(s, s, "test")
        #    threads[s].start()

        id = 0
        for cb in self.commentsList:
            csvDict1 = {}
            spl = cb.splitList
            print(str(id) + "/" + str(len(self.commentsList)))
            for i in range(0, len(spl)):
                # Set to zero all features
                for key in reducedBag:
                    csvDict1[key] = 0
                # Update the featurs in accord to the split word list
                for word in spl[i]:
                    cat = word.rstrip()
                    if args.lowercase is "true":
                        cat = cat.lower()
                    if cat in reducedBag:
                        csvDict1[cat] += 1
                csvDict1['ID'] = str(id)
                id += 1
                csvDict1['Global ID'] = cb.id
                csvDict1['File ID'] = cb.fileIndex
                csvDict1['Row ID'] = str(i)
                csvDict1['Row number'] = int(cb.rowPosition) + i
                csvDict1['File path'] = cb.filePath
                csvDict1['Top Category'] = cb.topCategory
                csvDict1['Inner Category'] = cb.innerCategory
                csvDict1['Number of characters'] = cb.numberOfCharacters
                csvDict1['Number of rows'] = len(re.findall('\n', cb.text)) + 1
                csvDict1['Number of words'] = len(spl[i])  # cb.numberOfWords
                csvDict1['Unique words'] = len(set(spl[i]))


                #
                # csvDict1['Summary'] = threads['Summary'].featureSummary()

                # for s in ss:
                #    csvDict1[s] = threads[s].join()

                # Handle special features
                f = Features(cb)

                csvDict1['Summary'] = f.featureSummary()
                csvDict1['Expand'] = f.featureExpand()
                csvDict1['Rational'] = f.featureRational()
                csvDict1['Deprecation'] = f.featureDeprecation()
                csvDict1['Usage'] = f.featureUsage()
                csvDict1['Exception'] = f.featureException()
                csvDict1['TODO'] = f.featureTODO()
                csvDict1['Incomplete'] = f.featureIncomplete()
                csvDict1['Commented code'] = f.featureCommentedCode()
                csvDict1['Directive'] = f.featureDirective()
                csvDict1['Formatter'] = f.featureFormatter()
                csvDict1['License'] = f.featureLicense()
                csvDict1['Ownership'] = f.featureOwnership()
                csvDict1['Pointer'] = f.featurePointer()
                csvDict1['Automatic generated'] = f.featureAutomaticGenerated()

                # Flush data to file
                if "/home/luca/data/Comments/projects/luca" in csvDict1['File path']:
                    csvWriterTesting.writerow(csvDict1)
                else:
                    csvWriterTraining.writerow(csvDict1)

                    # # Print some statistics
                    # print("\n********** Statistics **********\n")
                    # numberOfComments = len(self.commentsList)
                    # print("Number of comments: " + str(numberOfComments))
                    #
                    # numberOfLines = 0
                    # for cb in self.commentsList:
                    #     numberOfLines += int(cb.numberOfRows)
                    # print("Number of lines: " + str(numberOfLines))
                    #
                    # # Quante vole capita che una riga è composta da più tipologie di commenti
                    # tempList = []
                    # for cb in self.commentsList:
                    #     for i in range(0, int(cb.numberOfRows)):
                    #         tempList.append(cb.id + "_" + str(int(cb.rowPosition) + i))
                    # print("Number of lines with multiple comments: " + str(len(tempList) - len(set(tempList))))
                    #
                    # tempList = []
                    # for cb in self.commentsList:
                    #     if int(cb.numberOfRows) > 1:
                    #         tempList.append(cb.numberOfRows)
                    # print("Number of comments with multiple lines: " + str(len(tempList)))
                    #
                    # tempList = []
                    # for cb in self.commentsList:
                    #     tempList.append(cb.innerCategory)
                    # tempSet = set(tempList)
                    # print("\nNumber of categories found: " + str(len(tempSet)))
                    #
                    # # Print the number of comments by category
                    # tempDict1 = {}
                    # tempDict2 = {}
                    # for key in tempSet:
                    #     tempDict1[key] = 0
                    #     tempDict2[key] = 0
                    #     for cb in self.commentsList:
                    #         if key in cb.innerCategory:
                    #             tempDict1[key] += 1
                    #             tempDict2[key] += int(cb.numberOfRows)
                    #
                    # print("Category name\tNumber of comments\tNumber of lines\tNum of lines with multiple cats")
                    # for cat in sorted(tempDict1, key=tempDict1.get, reverse=True):
                    #     n = self.numberOfLinesWithMultipleComments(cat)
                    #     print("%-20s;%-25d;%-25d;%d" % (cat, tempDict1[cat], tempDict2[cat], n))

    def numberOfLinesWithMultipleComments(self, category):
        n = 0
        tempList1 = []
        tempList2 = []
        for cb in self.commentsList:
            if category in cb.innerCategory:
                for i in range(0, int(cb.numberOfRows)):
                    tempList1.append(cb.id + "_" + str(int(cb.rowPosition) + i))
        for id in tempList1:
            for cb in self.commentsList:
                if not category in cb.innerCategory:
                    for i in range(0, int(cb.numberOfRows)):
                        if id == cb.id + "_" + str(int(cb.rowPosition) + i):
                            tempList2.append(cb)
        # n = len(tempList2) - len(tempList1)
        n = len(tempList2)
        return n

    def readTextFromFile(self, path):
        out = open(path, "r")
        allText = out.read()
        return allText

    def readSplitFromFile(self, path):
        out = open(path, "r")
        lines = out.readlines()
        return lines

    def createFeatureHeader(self, bagOfWords):
        featureFields = ['ID', 'Global ID', 'File ID', 'Row ID', 'Row number', 'File path', 'Top Category', 'Inner Category', 'Number of characters', 'Number of rows', 'Number of words', 'Unique words']
        specialFeatures = ['Summary', 'Expand', 'Rational', 'Deprecation', 'Usage', 'Exception', 'TODO', 'Incomplete', 'Commented code', 'Directive', 'Formatter', 'License', 'Ownership', 'Pointer', 'Automatic generated']

        for key in specialFeatures:
            featureFields.append(key)

        for key in bagOfWords:
            featureFields.append(key)
        return featureFields

    def createFeatureCSVFile(self, path, header):
        outCSVFile = open(path, 'w', newline='')
        outWriter = csv.DictWriter(outCSVFile, fieldnames=header)
        outWriter.writeheader()
        return outWriter

    # def appendRowToCSV(self, ):

    def createBagOfUniqueWords(self, commentList, args):
        bag = {}
        # Create the bag of unique words from a whole comment (multiple lines allowed)
        for cb in commentList:
            sp = cb.split
            for word in sp:
                w = word.rstrip()
                if args.lowercase is "true":
                    w = w.lower()
                if not w in bag:
                    bag[w] = 1
                else:
                    bag[w] += 1
        return bag

    def removeWords(self, bag, occ):
        newBag = {}
        # Create the bag of unique words
        for key in bag:
            if bag[key] > int(occ):
                newBag[key] = bag[key]
        # Remove words from known list
        wordList = ['//', '/*', '**', '/', '*', '*/', '///']
        for word in wordList:
            if word in newBag:
                newBag.pop(word)
        return newBag

    def printBag(self, bag, args):
        print()
        if args.print is "true":
            sorted_x = sorted(bag.items(), key=operator.itemgetter(1))
            for i in sorted_x:
                print(i[0] + ": " + str(bag[i[0]]))
            print("Items: " + str(len(bag)))
