This appendix material refers to "Classifying code comments in Java open-source software systems" In Proceedings of the 14th International Conference on Mining Software Repositories (MSR-2017).

The package contains:

1. The folder `ClassifierExample` contains the source code of the tool `ComMean`, which we created to help the manual classification of comments in real-world source code files. The folder also contains an example. `ComMean` is implemented as a web application, which can be run by executing `main/runServer.sh`, then and opening the browser on [http://localhost:8088/](http://localhost:8088/).

The application has a single user _Luca_ with a couple of files partially classified as examples.

`ComMean` generates a file `<user-name>.csv` in results folder. 
The sub-folder `ClassifierExample/sources` contains a copy of sources to analyze by user. The files named after the pattern `list-relative-<user-name>.XXX` are internally used for keeping track of the progress.
The sub-folder `<user-name>` contains the actual sources of a given project.

2. `projects` contains a copy of all repositories as a snapshot at the time of the analysis from which we randomly selected source code files from each project and analyzed their comments, by means of `ComMean`.

3. `listOfComments` contains the manual classified comments (result of the manual classification done with `ComMean`), organized in sub-folders:
  - The sub-folder `int` contains the list of blocks of code comments manually labeled with `ComMean`. 
  - The sub-folder `cat` organizes the comments into sub-sub-folders, one per category of comment. Each file in these sub-sub-folders refers to the manual selected input (for example, `listOfComments/cat/directive/81.txt` is the comment number `81`, which has been classified as a comment of type _directive_).
  - The sub-folder `div` divides previous comments per line. Every file has two numbers separated by an underscore. The first number is the index of the file (same that you find in the `cat` and `int` folders), and the second number is the line number in the given block.
  - The sub-folder `split` splits each line belonging to the sub-folder `div` in tokens that are later used as features for the proposed machine learner.
  - The file `Classification_output.csv` contains a list of comments per file.
  To correctly interpret this file, the first unstructured row contains a relative path to a given file, then `uniq` column is the identifier used in the previous sub-folder schema, `start` and `stop` are the beginning and ending characters of a comment in a file, `name` is the top and inner categories separated by `->`. Finally, `expl`, `source`, and `com` were experimental fields not used to the purpose of the paper.   

4. `CommentsFeaturesExtractor` contains a python script to transform the output of `comMean` into `listOfComments` format. It contains also a sample, `example.csv` is a simple classification example conducted inspecting the two Java files contained into folder `sources`.
This python scripts accepts a list of parameters as explained in `Args.py`. Default parameters are used to take as input `example.csv` and produce several files into `output` folder. The subfolder `CommentsList` contain the comment split by previous point. `GlobalInput.cvsv` is a index of such sub-folders and finally `training.csv` and `testing.csv` are the CSV files usable in Weka. 



5. `weka-3-b-1` contains the exact version of the [Weka](https://en.wikipedia.org/wiki/Weka_(machine_learning)) that we used at the time of the analysis.

6. `ResultsWith7` contains training and testing data used in Weka at the time of the analysis.   Code comments are separated by project and the CSVs represent the augmented bag-of-words model created to train machine learning models where every word that occurs at least 7 times is used as a feature in addition to the feature manually created per category to train the machine learning model.
  - The files `result.7.<input>.<classifier>.txt` report the expected results of running Weka using the machine learning approach `<classifier>`
  - `Training.<project>.csv` and `Testing.<project>.csv` contains all the inputs to train and test Weka classifiers. After importing these files in Weka you can perform your analysis by dropping unwanted columns. For example, you can load Training.csv that contains all the values of all projects that come from manual classification. Then, you can drop `ID`, `Global ID`, `File ID`, `Row ID`, `File path` that are only identifiers and useless for the training/testing phase.
  Finally for predicting `Top Categories` you must remove also `Inner Categories` column, and viceversa for predicting `Inner Categories`.
  `Training.csv` and `Testing.csv` combine all comments of all projects, while `Training.<project>.csv` and `Testing.<project>.csv` split comments per projects. 
  


## CONTACTS
For more info about this work, please contact the authors of the paper:
Luca Pascarella <L.Pascarella@tudelft.nl>
Magiel Bruntink <m.bruntink@sig.eu>
Alberto Bacchelli <bacchelli@ifi.uzh.ch>